@@ -66,7 +66,7 @@ if paver.doctools.has_sphinx:
         builtdocs.move(destdir)
     
     @task
-    @needs('html', "minilib", "generate_setup", old_sdist)
+    @needs("minilib", "generate_setup", old_sdist)
     def sdist():
         """Builds the documentation and the tarball."""
         pass
